@@ -1,15 +1,16 @@
 """Shim class to not have to depend on typing module in prod."""
+# mypy: ignore-errors
 import sys
 import warnings
-
+from typing import Any
 
 warnings.warn("josepy.magic_typing is deprecated and will be removed in a future release.",
               DeprecationWarning)
 
 
-class TypingClass(object):
+class TypingClass:
     """Ignore import errors by getting anything"""
-    def __getattr__(self, name):
+    def __getattr__(self, name: str) -> Any:
         return None
 
 
